#include <iostream>
#include <fstream>
using namespace std;

const int MAXS = 100;
const int MAXV = 100;
const int MAXP = 100;

enum TipoVisita {ECOGRAFIA, TAC, RISONANZA};

struct Paziente {
  char nome[MAXS];
  char cognome[MAXS];
  int identif;
};

struct ElencoPazienti {
  Paziente paz[MAXP];
  int numPaz;
};

struct Data {
  int giorno;
  int mese;
  int anno;
};

struct Visita {
  Data data;
  int idPaz; 
  TipoVisita tipVis;
};

struct Calendario {
  Visita vis[MAXV];
  int numVis;
};
 

bool caricaElenco(ElencoPazienti* pe, const char n[]) {
  fstream ff;
  ff.open(n, ios::in);
  if(!ff) return false;
  Paziente p; 
  while(ff >> p.nome >> p.cognome >> p.identif) {
    for(int i=0; i<pe->numPaz; i++)
      if(pe->paz[i].identif == p.identif) return false;
    pe->paz[pe->numPaz++] = p;
  }
  return true;
}

int confronta(Data a, Data b) {
  if(a.anno != b.anno) return a.anno - b.anno;
  if(a.mese != b.mese) return a.mese - b.mese;
  return a.giorno - b.giorno;
}

int nuovaVisita(const ElencoPazienti* pe, Calendario* pc, Visita v) {
  bool trovato = false;
  for(int i=0; i<pe->numPaz; i++)
    if(pe->paz[i].identif == v.idPaz) 
      trovato = true;
  if(!trovato || pc->numVis == MAXV)
    return -1;
  int index = 0;
  for(; index<pc->numVis && confronta(pc->vis[index].data, v.data) < 0; index++); 
  for(int i=pc->numVis; i>index; i--)
    pc->vis[i] =pc->vis[i-1];
  pc->vis[index] = v;
  pc->numVis++;
  return index;
}

bool primoPaziente(const ElencoPazienti* pe, const Calendario* pc, TipoVisita tv, Paziente* pp){
  int index = -1;
  for(int i=0; i<pc->numVis; i++)
    if(pc->vis[i].tipVis == tv) {
      index = i;
      break;
    }
  if(index == -1)
    return false;
  for(int i=0; i<pe->numPaz; i++)
    if(pe->paz[i].identif == pc->vis[index].idPaz){
      *pp =  pe->paz[i];
      return true;
    }
  return false;
}

int trovaVisite(const Calendario* pc, int id, Visita vv[]) {
  int conta = 0;
  for(int i=0; i<pc->numVis; i++) {
    if(pc->vis[i].idPaz == id)
      vv[conta++] = pc->vis[i];
  }
  return conta;
}

void stampaData(Data d) {
  cout << d.giorno << '/' << d.mese << '/' << d.anno; 
}

void stampaTipo(TipoVisita tv){
  switch(tv) {
    case TAC: cout << "TAC"; break;
    case RISONANZA: cout << "RIS"; break;
    case ECOGRAFIA: cout << "ECO"; break;
  }
}

void stampaReport(const ElencoPazienti* pe, const Calendario* pc, int id) {
  cout << "####################" << endl;
  for(int i=0; i<pe->numPaz; i++)
    if(pe->paz[i].identif == id) {
      cout << pe->paz[i].nome << ' ' << pe->paz[i].cognome << endl;
      break;
    }
  cout << "--------------------" << endl;
  Visita tmp[MAXV];
  int q = trovaVisite(pc, id, tmp); 
  for(int i=0; i<q; i++) {
    stampaData(tmp[i].data);
    cout << ' ';
    stampaTipo(tmp[i].tipVis);
    cout << endl;
  }
  cout << "####################" << endl;
}
